SystemOrganization addCategory: #ConfigurationOfHP35!

Object subclass: #ConfigurationOfHP35
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfHP35'!

!ConfigurationOfHP35 commentStamp: 'SvenVanCaekenberghe 6/25/2014 14:44' prior: 0!
I am ConfigurationOfHP35, a Metacello Configuration for the HP35 Calculator tutorial project.

Read the full tutorial article here: 

 Rediscovering the UX of the legendary HP-35 Scientific Pocket Calculator

  A tutorial on Pharo, test and specification based immersive programming

  https://medium.com/@svenvc/rediscovering-the-ux-of-the-legendary-hp-35-scientific-pocket-calculator-d1d497ece999

To load the code with the Spec UI you can do: 
 
  ConfigurationOfHP35 load.

To load the Seaside UI code (which will load Seaside and XML Support as well) do:

  ConfigurationOfHP35 project stableVersion load: 'Web-UI'.
!

!ConfigurationOfHP35 class methodsFor: 'development support' stamp: 'SvenVanCaekenberghe 6/19/2014 23:38'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfHP35 class methodsFor: 'private' stamp: 'SvenVanCaekenberghe 6/19/2014 23:38'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfHP35 class methodsFor: 'catalog' stamp: 'SvenVanCaekenberghe 6/23/2014 16:24'!
catalogChangeLog
	"Returns a paragraph describing the most important changes in the configuration class."
	^ 'First version released in June 2014'! !

!ConfigurationOfHP35 class methodsFor: 'catalog' stamp: 'SvenVanCaekenberghe 6/25/2014 14:44'!
catalogContactInfo
	"Returns a paragraph describing contact information such as email, mailing lists and website."
	^ 'Written and maintained by Sven Van Caekenberghe (http://stfx.eu). Discussions on the Pharo aling lists. Documentation can be found in the following article: https://medium.com/@svenvc/rediscovering-the-ux-of-the-legendary-hp-35-scientific-pocket-calculator-d1d497ece999'! !

!ConfigurationOfHP35 class methodsFor: 'catalog' stamp: 'SvenVanCaekenberghe 6/23/2014 16:29'!
catalogDescription
	"Returns a paragraph describing the project"
	^ 'A tutorial on Pharo, test and specification based immersive programming. The goal of the project is to model the UX aspects of the legendary HP-35 Scientific Pocket Calculator from 1972. We will build several simple GUIs, based on Spec and Seaside.'! !

!ConfigurationOfHP35 class methodsFor: 'catalog' stamp: 'SvenVanCaekenberghe 6/23/2014 16:31'!
catalogKeyClassesAndExample
	"Returns a paragraph or more describing the key classes of your project. You can use Pillar/Pier syntax to layout out the text i.e., ==Code== and - for bullet."
	^ 'The core classes are RPNCalculatorCore, HP35CalculatorModel, HP35CalculatorUIModel and HP35CalculatorWebComponent.'! !

!ConfigurationOfHP35 class methodsFor: 'catalog' stamp: 'SvenVanCaekenberghe 6/23/2014 16:30'!
catalogKeywords
	"Returns an array of symbols"
	^ #(testing specifications spec seaside ui web ajax tutorial example calculator rpn) ! !

!ConfigurationOfHP35 class methodsFor: 'private' stamp: 'SvenVanCaekenberghe 6/19/2014 23:38'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfHP35 class methodsFor: 'private' stamp: 'SvenVanCaekenberghe 6/19/2014 23:38'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfHP35 class methodsFor: 'metacello tool support' stamp: 'SvenVanCaekenberghe 6/19/2014 23:38'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfHP35 class methodsFor: 'loading' stamp: 'SvenVanCaekenberghe 6/19/2014 23:38'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfHP35 class methodsFor: 'loading' stamp: 'SvenVanCaekenberghe 6/19/2014 23:38'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfHP35 class methodsFor: 'loading' stamp: 'SvenVanCaekenberghe 6/19/2014 23:38'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfHP35 class methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 6/19/2014 23:38'!
project

	^self new project! !

!ConfigurationOfHP35 class methodsFor: 'development support' stamp: 'SvenVanCaekenberghe 6/19/2014 23:38'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfHP35 methodsFor: 'baselines' stamp: 'SvenVanCaekenberghe 6/23/2014 20:43'!
baseline1: spec
	<version: '1-baseline'>
	
	spec for: #common do: [
		spec 
			blessing: #baseline;
			author: 'Sven Van Caekenberghe';
			repository: 'http://smalltalkhub.com/mc/SvenVanCaekenberghe/HP35/main/'.

		spec project: 'Seaside3' with: [                                                     
 			spec
				className: 'ConfigurationOfSeaside3';
				versionString: #stable;
				repository: 'http://www.smalltalkhub.com/mc/Seaside/MetacelloConfigurations/main' ].

		spec project: 'XML Support' with: [
			spec
				className: 'ConfigurationOfXMLSupport';
				versionString: #stable;
				repository: 'http://www.squeaksource.com/MetacelloRepository' ].

		spec package: 'HP35-Calculator'.
		spec package: 'HP35-Seaside-Calculator' with: [ spec requires: #( 'HP35-Calculator' 'Seaside3' 'XML Support' ) ]. 

		spec group: 'Core' with:  #( 'HP35-Calculator' ).
		spec group: 'Web-UI' with: #( 'HP35-Seaside-Calculator' ).

		spec group: 'default' with:   #( 'Core' )  ]! !

!ConfigurationOfHP35 methodsFor: 'symbolic versions' stamp: 'SvenVanCaekenberghe 6/25/2014 13:48'!
development: spec
	<symbolicVersion: #'development'>
	
	spec for: #common version: '2'! !

!ConfigurationOfHP35 methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 6/19/2014 23:38'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfHP35 methodsFor: 'symbolic versions' stamp: 'SvenVanCaekenberghe 6/25/2014 13:48'!
stable: spec
	<symbolicVersion: #'stable'>
	
	spec for: #common version: '2'! !

!ConfigurationOfHP35 methodsFor: 'versions' stamp: 'SvenVanCaekenberghe 6/23/2014 16:20'!
version1: spec
	<version: '1' imports: #('1-baseline')>
	
	spec for: #common do: [
		spec
			blessing: #release;
			package: 'HP35-Calculator' with: 'HP35-Calculator-SvenVanCaekenberghe.16';
			package: 'HP35-Seaside-Calculator' with: 'HP35-Seaside-Calculator-SvenVanCaekenberghe.4' ]! !

!ConfigurationOfHP35 methodsFor: 'versions' stamp: 'SvenVanCaekenberghe 6/25/2014 13:47'!
version2: spec
	<version: '2' imports: #('1-baseline')>
	
	spec for: #common do: [
		spec
			blessing: #release;
			package: 'HP35-Calculator' with: 'HP35-Calculator-SvenVanCaekenberghe.17';
			package: 'HP35-Seaside-Calculator' with: 'HP35-Seaside-Calculator-SvenVanCaekenberghe.4' ]! !
